@@ -299,11 +299,15 @@ class Interface(object):
         return -- dict -- the same dict, but now prepared
         """
         # update the times
-        # http://crazytechthoughts.blogspot.com/2012/02/get-current-utc-timestamp-in-python.html
-        now = calendar.timegm(datetime.datetime.utcnow().utctimetuple())
+        now = datetime.datetime.utcnow()
+        field_created = schema._created
+        field_updated = schema._updated
         if is_insert:
-            d[schema._created] = now
-        d[schema._updated] = now
+            if field_created not in d:
+                d[field_created] = now
+
+        if field_updated not in d:
+            d[field_updated] = now
 
         return d
 
@@ -486,10 +490,13 @@ class Interface(object):
         **log_options -- 
             level -- something like logging.DEBUG
         """
-        log_level = log_options.get('level', logging.DEBUG)
-        if logger.isEnabledFor(log_level):
-            if format_args:
-                logger.log(log_level, format_str.format(*format_args))
-            else:
-                logger.log(log_level, format_str)
+        if isinstance(format_str, Exception):
+            logger.exception(format_str, *format_args)
+        else:
+            log_level = log_options.get('level', logging.DEBUG)
+            if logger.isEnabledFor(log_level):
+                if format_args:
+                    logger.log(log_level, format_str.format(*format_args))
+                else:
+                    logger.log(log_level, format_str)
 
